@@ -44,7 +44,7 @@ use SDL::Constants;
 
 BEGIN {
 	@ISA = qw(Exporter DynaLoader);
-	@EXPORT = qw( in verify &NULL );
+	@EXPORT = qw( in &NULL );
 };
 
 # Give our caller SDL::Constant's stuff as well as ours.
@@ -54,7 +54,7 @@ sub import {
   $self->export_to_level(1, @_);
   SDL::Constants->export_to_level(1);
 }
-our $VERSION = '2.3_3'; #Development Release
+our $VERSION = '2.3_5'; #Development Release
 $VERSION = eval $VERSION;
 
 print "$VERSION" if (defined($ARGV[0]) && ($ARGV[0] eq '--SDLperl'));
@@ -65,22 +65,6 @@ sub NULL {
 	return 0;
 }
 
-sub in {
-	my ($k,@t) = @_;
-	return 0 unless defined $k;
-	my $r = ((scalar grep { defined $_ && $_ eq $k } @t) <=> 0);
-	return 0 if $r eq '';
-	return $r;
-
-} 
-
-sub verify (\%@) {
-	my ($options,@valid_options) = @_;
-	for (keys %$options) {
-		croak "Invalid option $_\n" unless in ($_, @valid_options);
-	}
-}
-
 # workaround as:
 # extern DECLSPEC void SDLCALL SDL_SetError(const char *fmt, ...);
 sub set_error {
